pub struct Gate;Implementations
Sourceimpl Gate
impl Gate
Sourcepub fn run(summary: &MetricsSummary, baseline: &Baseline) -> QualityReport
pub fn run(summary: &MetricsSummary, baseline: &Baseline) -> QualityReport
Compare a metrics summary against a baseline and produce a quality report.
Sourcepub fn run_with_config(
summary: &MetricsSummary,
baseline: &Baseline,
config: Option<&GateConfig>,
) -> QualityReport
pub fn run_with_config( summary: &MetricsSummary, baseline: &Baseline, config: Option<&GateConfig>, ) -> QualityReport
Compare metrics against baseline with optional absolute thresholds.
When config is provided, absolute values override baseline ratchet values.